@@ -238,17 +238,6 @@ class EventsView(RouteView):
         self.mbd_events = _events[0:self.mbd_limit]
 
 
-class BuildsView(RouteView):
-    template_name = "mini_buildd/builds/index.html"
-
-    def setup(self, request, *args, **kwargs):
-        super().setup(request, *args, **kwargs)
-        self.mbd_before, self.mbd_limit = self.mbd_get_range()
-        buildlogs = sorted(self.mbd_route.path.ifiles(self.mbd_path, ".buildlog", before=self.mbd_before), key=lambda e: e.stat().st_mtime, reverse=True)
-        self.mbd_buildlogs_total = len(buildlogs)
-        self.mbd_buildlogs = {util.Datetime.from_stamp(entry.stat().st_mtime): self.mbd_route.path.removeprefix(entry.path) for entry in buildlogs[0:self.mbd_limit]}
-
-
 class RepositoriesView(RouteView):
     @classmethod
     def mbd_parse_distribution(cls, repo, dist, suite):
@@ -287,16 +276,14 @@ class APIView(TemplateView):
 
         def __init__(self):
             super().__init__()
-            for name, call in api.CALLS.items():
-                html_snippet = call.CUSTOM_HTML_SNIPPET if call.CUSTOM_HTML_SNIPPET is not None else name
-                path = f"mini_buildd/includes/api/{html_snippet}.html"
+            for name in api.CALLS:
+                path = f"mini_buildd/includes/api/{name}.html"
                 try:
                     django.template.loader.get_template(path)
                     self[name] = path
-                    LOG.debug(f"API call '{name}' uses HTML snippet: {path}")
                 except django.template.TemplateDoesNotExist:
                     self[name] = "mini_buildd/includes/api/default.html"
-                    LOG.debug(f"API call '{name}' uses default HTML snippet")
+                LOG.debug(f"API call '{name}' uses HTML snippet: {self[name]}")
 
     MBD_API_SNIPPETS = Snippets()
 
